from setuptools import setup


setup(name='keras-dense-sparse-matmul',
      version='0.3.0',
      description='deprecated. Please use "keras_tweaks.dense_sparse_matmul" instead.',
      url='http://github.com/kmedian',
      author='Ulf Hamster',
      author_email='554c46@gmail.com',
      license='Apache License 2.0',
      packages=['keras_dense_sparse_matmul'],
      install_requires=['setuptools>=40.0.0'],
      python_requires='>=3.6',
      zip_safe=False)
